Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(257)

Unified Diff: components/html_viewer/html_frame_tree_manager.h

Issue 1340983002: Mandoline UI Process: Update namespaces and file names (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebased Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/html_viewer/html_frame_apptest.cc ('k') | components/html_viewer/html_frame_tree_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/html_viewer/html_frame_tree_manager.h
diff --git a/components/html_viewer/html_frame_tree_manager.h b/components/html_viewer/html_frame_tree_manager.h
index 61ea86ffa25662cda46c21f8c3d3e5df0501f215..bbd2d6642244f0bd17862625a303f00f9231881b 100644
--- a/components/html_viewer/html_frame_tree_manager.h
+++ b/components/html_viewer/html_frame_tree_manager.h
@@ -18,7 +18,7 @@ namespace blink {
class WebView;
}
-namespace mojo {
+namespace mus {
class View;
}
@@ -34,7 +34,7 @@ class HTMLFrameTreeManagerObserver;
// document. Some of the frames may be remote. HTMLFrameTreeManager updates its
// state in response to changes from the FrameTreeServer, as well as changes
// from the underlying frames. The frame tree has at least one local frame
// that is backed by a mojo::View.
class HTMLFrameTreeManager {
public:
// Returns a new HTMLFrame or null if a HTMLFrame does not need to be created.
@@ -42,7 +42,7 @@ class HTMLFrameTreeManager {
// Close() when done.
static HTMLFrame* CreateFrameAndAttachToTree(
GlobalState* global_state,
- mojo::View* view,
+ mus::View* view,
scoped_ptr<DocumentResourceWaiter> resource_waiter,
HTMLFrameDelegate* delegate);
@@ -71,7 +71,7 @@ class HTMLFrameTreeManager {
~HTMLFrameTreeManager();
void Init(HTMLFrameDelegate* delegate,
- mojo::View* local_view,
+ mus::View* local_view,
const mojo::Array<web_view::FrameDataPtr>& frame_data,
uint32_t change_id);
@@ -80,7 +80,7 @@ class HTMLFrameTreeManager {
HTMLFrameDelegate* delegate,
const mojo::Array<web_view::FrameDataPtr>& frame_data,
uint32_t local_frame_id,
- mojo::View* local_view);
+ mus::View* local_view);
// Returns this HTMLFrameTreeManager from |instances_|.
void RemoveFromInstances();
« no previous file with comments | « components/html_viewer/html_frame_apptest.cc ('k') | components/html_viewer/html_frame_tree_manager.cc » ('j') | no next file with comments »
@@ -34,7 +34,7 @@ class HTMLFrameTreeManagerObserver;
// state in response to changes from the FrameTreeServer, as well as changes
// from the underlying frames. The frame tree has at least one local frame
-// that is backed by a mojo::View.
+// that is backed by a mus::View.
class HTMLFrameTreeManager {
public:

Powered by Google App Engine
This is Rietveld 408576698